pub struct JackOutputSourceUpdater<'a> { /* private fields */ }Available on Linux only.
Used to update the source this updater was created from. For more details look at docs for the corresponding builder.
Implementations
Sourceimpl<'a> JackOutputSourceUpdater<'a>
impl<'a> JackOutputSourceUpdater<'a>
Sourcepub fn set_start_jack<T: Into<ObsString> + Sync + Send>(
self,
start_jack: T,
) -> Self
pub fn set_start_jack<T: Into<ObsString> + Sync + Send>( self, start_jack: T, ) -> Self
Whether the JACK server should start when the source is created
pub fn set_channels(self, channels: i64) -> Self