pub struct PipeWireCameraSourceUpdater<'a> { /* private fields */ }Available on Linux only.
Used to update the source this updater was created from. For more details look at docs for the corresponding builder.
Implementations
Sourceimpl<'a> PipeWireCameraSourceUpdater<'a>
impl<'a> PipeWireCameraSourceUpdater<'a>
Sourcepub fn set_camera_id<T: Into<ObsString> + Sync + Send>(
self,
camera_id: T,
) -> Self
pub fn set_camera_id<T: Into<ObsString> + Sync + Send>( self, camera_id: T, ) -> Self
Camera device node (e.g., “/dev/video0”)
Sourcepub fn set_video_format<T: Into<ObsString> + Sync + Send>(
self,
video_format: T,
) -> Self
pub fn set_video_format<T: Into<ObsString> + Sync + Send>( self, video_format: T, ) -> Self
Video format (FOURCC as string)
Sourcepub fn set_resolution<T: Into<ObsString> + Sync + Send>(
self,
resolution: T,
) -> Self
pub fn set_resolution<T: Into<ObsString> + Sync + Send>( self, resolution: T, ) -> Self
Resolution as “width x height”
Sourcepub fn set_framerate<T: Into<ObsString> + Sync + Send>(
self,
framerate: T,
) -> Self
pub fn set_framerate<T: Into<ObsString> + Sync + Send>( self, framerate: T, ) -> Self
Framerate as “num/den”