PulseInputSourceBuilder

Struct PulseInputSourceBuilder 

pub struct PulseInputSourceBuilder { /* private fields */ }
Available on Linux only.
A source for PulseAudio audio input.

This source captures audio from PulseAudio devices on Linux systems. PulseAudio is a higher-level sound server that sits on top of ALSA and provides more advanced audio routing and mixing capabilities.

Implementations

Source

impl PulseInputSourceBuilder

pub fn set_device_id<T: Into<ObsString> + Sync + Send>( self, device_id: T, ) -> Self

PulseAudio device name/ID

Source

impl PulseInputSourceBuilder

pub fn set_default_device(self) -> Self

Set the default PulseAudio input device