pub struct PulseOutputSourceBuilder { /* private fields */ }Available on Linux only.
A source for PulseAudio audio input.
This source captures audio from PulseAudio devices on Linux systems. PulseAudio is a higher-level sound server that sits on top of ALSA and provides more advanced audio routing and mixing capabilities.
Implementations
Sourceimpl PulseOutputSourceBuilder
impl PulseOutputSourceBuilder
Sourcepub fn set_device_id<T: Into<ObsString> + Sync + Send>(
self,
device_id: T,
) -> Self
pub fn set_device_id<T: Into<ObsString> + Sync + Send>( self, device_id: T, ) -> Self
PulseAudio device name/ID
Sourceimpl PulseOutputSourceBuilder
impl PulseOutputSourceBuilder
Sourcepub fn set_default_device(self) -> Self
pub fn set_default_device(self) -> Self
Set the default PulseAudio output device