PipeWireSourceExtTrait

Trait PipeWireSourceExtTrait 

pub trait PipeWireSourceExtTrait {
    // Required method
    fn get_restore_token(&self) -> Result<Option<String>, ObsError>;
}
Available on Linux only.
This trait provides additional methods for PipeWire sources.

Required Methods

fn get_restore_token(&self) -> Result<Option<String>, ObsError>

Gets the restore token used for reconnecting to previous sessions for pipewire-desktop-capture-source and pipewire-window-capture-source sources.

As of right now, there is no callback or signal to notify when the token has been set, you have to call this method to get the restore token.

The restore token will most probably be of Some(String) after the user has selected a screen or window to capture.

Implementations on Foreign Types

Source

impl PipeWireSourceExtTrait for ObsSourceRef

Implementors